package java.io;

public class CharArrayWriter extends Writer {
   protected char[] buf;
   protected int count;

   public CharArrayWriter() {
      this(32);
   }

   public CharArrayWriter(int var1) {
      if (var1 < 0) {
         throw new IllegalArgumentException("Negative initial size: " + var1);
      } else {
         this.buf = new char[var1];
      }
   }

   public void write(int var1) {
      Object var2 = super.lock;
      synchronized(var2) {
         int var3 = this.count + 1;
         if (var3 > this.buf.length) {
            char[] var4 = new char[Math.max(this.buf.length << 1, var3)];
            System.arraycopy(this.buf, 0, var4, 0, this.count);
            this.buf = var4;
         }

         this.buf[this.count] = (char)var1;
         this.count = var3;
      }
   }

   public void write(char[] var1, int var2, int var3) {
      if (var2 >= 0 && var2 <= var1.length && var3 >= 0 && var2 + var3 <= var1.length && var2 + var3 >= 0) {
         if (var3 != 0) {
            Object var4 = super.lock;
            synchronized(var4) {
               int var5 = this.count + var3;
               if (var5 > this.buf.length) {
                  char[] var6 = new char[Math.max(this.buf.length << 1, var5)];
                  System.arraycopy(this.buf, 0, var6, 0, this.count);
                  this.buf = var6;
               }

               System.arraycopy(var1, var2, this.buf, this.count, var3);
               this.count = var5;
            }
         }
      } else {
         throw new IndexOutOfBoundsException();
      }
   }

   public void write(String var1, int var2, int var3) {
      Object var4 = super.lock;
      synchronized(var4) {
         int var5 = this.count + var3;
         if (var5 > this.buf.length) {
            char[] var6 = new char[Math.max(this.buf.length << 1, var5)];
            System.arraycopy(this.buf, 0, var6, 0, this.count);
            this.buf = var6;
         }

         var1.getChars(var2, var2 + var3, this.buf, this.count);
         this.count = var5;
      }
   }

   public void writeTo(Writer var1) throws IOException {
      Object var2 = super.lock;
      synchronized(var2) {
         var1.write(this.buf, 0, this.count);
      }
   }

   public void reset() {
      this.count = 0;
   }

   public char[] toCharArray() {
      Object var1 = super.lock;
      synchronized(var1) {
         char[] var2 = new char[this.count];
         System.arraycopy(this.buf, 0, var2, 0, this.count);
         return var2;
      }
   }

   public int size() {
      return this.count;
   }

   public String toString() {
      Object var1 = super.lock;
      synchronized(var1) {
         String var2 = new String(this.buf, 0, this.count);
         return var2;
      }
   }

   public void flush() {
   }

   public void close() {
   }
}
