package java.io;

public class DataInputStream extends FilterInputStream implements DataInput {
   private char[] lineBuffer;

   public DataInputStream(InputStream var1) {
      super(var1);
   }

   public final int read(byte[] var1) throws IOException {
      return super.in.read(var1, 0, var1.length);
   }

   public final int read(byte[] var1, int var2, int var3) throws IOException {
      return super.in.read(var1, var2, var3);
   }

   public final void readFully(byte[] var1) throws IOException {
      this.readFully(var1, 0, var1.length);
   }

   public final void readFully(byte[] var1, int var2, int var3) throws IOException {
      if (var3 < 0) {
         throw new IndexOutOfBoundsException();
      } else {
         InputStream var4 = super.in;

         int var6;
         for(int var5 = 0; var5 < var3; var5 += var6) {
            var6 = var4.read(var1, var2 + var5, var3 - var5);
            if (var6 < 0) {
               throw new EOFException();
            }
         }

      }
   }

   public final int skipBytes(int var1) throws IOException {
      InputStream var2 = super.in;
      int var3 = 0;

      int var5;
      for(var5 = 0; var3 < var1 && (var5 = (int)var2.skip((long)(var1 - var3))) > 0; var3 += var5) {
      }

      return var3;
   }

   public final boolean readBoolean() throws IOException {
      int var1 = super.in.read();
      if (var1 < 0) {
         throw new EOFException();
      } else {
         return var1 != 0;
      }
   }

   public final byte readByte() throws IOException {
      int var1 = super.in.read();
      if (var1 < 0) {
         throw new EOFException();
      } else {
         return (byte)var1;
      }
   }

   public final int readUnsignedByte() throws IOException {
      int var1 = super.in.read();
      if (var1 < 0) {
         throw new EOFException();
      } else {
         return var1;
      }
   }

   public final short readShort() throws IOException {
      InputStream var1 = super.in;
      int var2 = var1.read();
      int var3 = var1.read();
      if ((var2 | var3) < 0) {
         throw new EOFException();
      } else {
         return (short)((var2 << 8) + (var3 << 0));
      }
   }

   public final int readUnsignedShort() throws IOException {
      InputStream var1 = super.in;
      int var2 = var1.read();
      int var3 = var1.read();
      if ((var2 | var3) < 0) {
         throw new EOFException();
      } else {
         return (var2 << 8) + (var3 << 0);
      }
   }

   public final char readChar() throws IOException {
      InputStream var1 = super.in;
      int var2 = var1.read();
      int var3 = var1.read();
      if ((var2 | var3) < 0) {
         throw new EOFException();
      } else {
         return (char)((var2 << 8) + (var3 << 0));
      }
   }

   public final int readInt() throws IOException {
      InputStream var1 = super.in;
      int var2 = var1.read();
      int var3 = var1.read();
      int var4 = var1.read();
      int var5 = var1.read();
      if ((var2 | var3 | var4 | var5) < 0) {
         throw new EOFException();
      } else {
         return (var2 << 24) + (var3 << 16) + (var4 << 8) + (var5 << 0);
      }
   }

   public final long readLong() throws IOException {
      InputStream var1 = super.in;
      return ((long)this.readInt() << 32) + ((long)this.readInt() & 4294967295L);
   }

   public final float readFloat() throws IOException {
      return Float.intBitsToFloat(this.readInt());
   }

   public final double readDouble() throws IOException {
      return Double.longBitsToDouble(this.readLong());
   }

   public final String readLine() throws IOException {
      InputStream var1 = super.in;
      char[] var2 = this.lineBuffer;
      if (var2 == null) {
         var2 = this.lineBuffer = new char[128];
      }

      int var3 = var2.length;
      int var4 = 0;

      while(true) {
         int var5;
         switch (var5 = var1.read()) {
            case 13:
               int var6 = var1.read();
               if (var6 != 10 && var6 != -1) {
                  if (!(var1 instanceof PushbackInputStream)) {
                     var1 = super.in = new PushbackInputStream(var1);
                  }

                  ((PushbackInputStream)var1).unread(var6);
               }
            case -1:
            case 10:
               if (var5 == -1 && var4 == 0) {
                  return null;
               }

               return String.copyValueOf(var2, 0, var4);
         }

         --var3;
         if (var3 < 0) {
            var2 = new char[var4 + 128];
            var3 = var2.length - var4 - 1;
            System.arraycopy(this.lineBuffer, 0, var2, 0, var4);
            this.lineBuffer = var2;
         }

         var2[var4++] = (char)var5;
      }
   }

   public final String readUTF() throws IOException {
      return readUTF(this);
   }

   public static final String readUTF(DataInput var0) throws IOException {
      int var1 = var0.readUnsignedShort();
      StringBuffer var2 = new StringBuffer(var1);
      byte[] var3 = new byte[var1];
      int var7 = 0;
      var0.readFully(var3, 0, var1);

      while(var7 < var1) {
         int var4 = var3[var7] & 255;
         switch (var4 >> 4) {
            case 0:
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
               ++var7;
               var2.append((char)var4);
               break;
            case 8:
            case 9:
            case 10:
            case 11:
            default:
               throw new UTFDataFormatException();
            case 12:
            case 13:
               var7 += 2;
               if (var7 > var1) {
                  throw new UTFDataFormatException();
               }

               byte var8 = var3[var7 - 1];
               if ((var8 & 192) != 128) {
                  throw new UTFDataFormatException();
               }

               var2.append((char)((var4 & 31) << 6 | var8 & 63));
               break;
            case 14:
               var7 += 3;
               if (var7 > var1) {
                  throw new UTFDataFormatException();
               }

               byte var5 = var3[var7 - 2];
               byte var6 = var3[var7 - 1];
               if ((var5 & 192) != 128 || (var6 & 192) != 128) {
                  throw new UTFDataFormatException();
               }

               var2.append((char)((var4 & 15) << 12 | (var5 & 63) << 6 | (var6 & 63) << 0));
         }
      }

      return new String(var2);
   }
}
