package java.io;

import sun.io.ByteToCharConverter;
import sun.io.ConversionBufferFullException;

public class InputStreamReader extends Reader {
   private ByteToCharConverter btc;
   // $FF: renamed from: in java.io.InputStream
   private InputStream field_0;
   private static final int defaultByteBufferSize = 8192;
   // $FF: renamed from: bb byte[]
   private byte[] field_1;
   private int nBytes;
   private int nextByte;

   public InputStreamReader(InputStream var1) {
      this(var1, ByteToCharConverter.getDefault());
   }

   public InputStreamReader(InputStream var1, String var2) throws UnsupportedEncodingException {
      this(var1, ByteToCharConverter.getConverter(var2));
   }

   private InputStreamReader(InputStream var1, ByteToCharConverter var2) {
      super(var1);
      this.nBytes = 0;
      this.nextByte = 0;
      if (var1 == null) {
         throw new NullPointerException("input stream is null");
      } else {
         this.field_0 = var1;
         this.btc = var2;
         this.field_1 = new byte[8192];
      }
   }

   public String getEncoding() {
      Object var1 = super.lock;
      synchronized(var1) {
         if (this.btc != null) {
            String var2 = this.btc.getCharacterEncoding();
            return var2;
         } else {
            Object var3 = null;
            return (String)var3;
         }
      }
   }

   private void malfunction() {
      throw new InternalError("Converter malfunction (" + this.btc.getCharacterEncoding() + ") -- please submit a bug report via " + System.getProperty("java.vendor.url.bug"));
   }

   private int convertInto(char[] var1, int var2, int var3) throws IOException {
      int var4 = 0;
      if (this.nextByte < this.nBytes) {
         try {
            var4 = this.btc.convert(this.field_1, this.nextByte, this.nBytes, var1, var2, var3);
            this.nextByte = this.nBytes;
            if (this.btc.nextByteIndex() != this.nextByte) {
               this.malfunction();
            }
         } catch (ConversionBufferFullException var6) {
            this.nextByte = this.btc.nextByteIndex();
            var4 = this.btc.nextCharIndex() - var2;
         }
      }

      return var4;
   }

   private int flushInto(char[] var1, int var2, int var3) throws IOException {
      int var4 = 0;

      try {
         var4 = this.btc.flush(var1, var2, var3);
      } catch (ConversionBufferFullException var6) {
         var4 = this.btc.nextCharIndex() - var2;
      }

      return var4;
   }

   private int fill(char[] var1, int var2, int var3) throws IOException {
      int var4 = 0;
      if (this.nextByte < this.nBytes) {
         var4 = this.convertInto(var1, var2, var3);
      }

      while(var2 + var4 < var3) {
         if (this.nBytes != -1) {
            if (var4 > 0 && !this.inReady()) {
               break;
            }

            this.nBytes = this.field_0.read(this.field_1);
         }

         if (this.nBytes == -1) {
            this.nBytes = 0;
            var4 += this.flushInto(var1, var2 + var4, var3);
            if (var4 == 0) {
               return -1;
            }
            break;
         }

         this.nextByte = 0;
         var4 += this.convertInto(var1, var2 + var4, var3);
      }

      return var4;
   }

   private boolean inReady() {
      try {
         return this.field_0.available() > 0;
      } catch (IOException var2) {
         return false;
      }
   }

   private void ensureOpen() throws IOException {
      if (this.field_0 == null) {
         throw new IOException("Stream closed");
      }
   }

   public int read() throws IOException {
      char[] var1 = new char[1];
      return this.read(var1, 0, 1) == -1 ? -1 : var1[0];
   }

   public int read(char[] var1, int var2, int var3) throws IOException {
      Object var4 = super.lock;
      synchronized(var4) {
         this.ensureOpen();
         if (var2 >= 0 && var2 <= var1.length && var3 >= 0 && var2 + var3 <= var1.length && var2 + var3 >= 0) {
            if (var3 == 0) {
               byte var8 = 0;
               return var8;
            } else {
               int var5 = this.fill(var1, var2, var2 + var3);
               return var5;
            }
         } else {
            throw new IndexOutOfBoundsException();
         }
      }
   }

   public boolean ready() throws IOException {
      Object var1 = super.lock;
      synchronized(var1) {
         this.ensureOpen();
         boolean var2 = this.nextByte < this.nBytes || this.inReady();
         return var2;
      }
   }

   public void close() throws IOException {
      Object var1 = super.lock;
      synchronized(var1) {
         if (this.field_0 != null) {
            this.field_0.close();
            this.field_0 = null;
            this.field_1 = null;
            this.btc = null;
         }
      }
   }
}
